@@ -91,15 +91,15 @@ class TransactionChecks(object):
             self._rollback_and_reload()
             self.assertEqual(self.obj.field, None)
         finally:
+            transaction.rollback()
             transaction.leave_transaction_management()
 
 
 # Non-transaction tests
 
 
-class TestsWorkWithPlainDjangoTestCase(
-    DjangoTestCase,
-    PlainDatabaseChecks):
+class TestsWorkWithPlainDjangoTestCase(DjangoTestCase,
+                                       PlainDatabaseChecks):
     """
     Test class that is using:
         * plain database checks
@@ -107,9 +107,8 @@ class TestsWorkWithPlainDjangoTestCase(
     """
 
 
-class TestsWorkWithTestToolsTestCase(
-    TestCase,
-    PlainDatabaseChecks):
+class TestsWorkWithTestToolsTestCase(TestCase,
+                                     PlainDatabaseChecks):
     """
     Test class that is using:
         * plain database checks
@@ -117,9 +116,8 @@ class TestsWorkWithTestToolsTestCase(
     """
 
 
-class TestsWorkWithTestScenariosTestCaseAndNoScenarios(
-    TestCaseWithScenarios,
-    PlainDatabaseChecks):
+class TestsWorkWithTestScenariosTestCaseAndNoScenarios(TestCaseWithScenarios,
+                                                       PlainDatabaseChecks):
     """
     Test class that is using:
         * plain database checks
@@ -129,10 +127,9 @@ class TestsWorkWithTestScenariosTestCaseAndNoScenarios(
     """
 
 
-class TestsWorkWithTestScenariosTestCaseAndSomeScenarios(
-    TestCaseWithScenarios,
-    ScenarioParametersAreVisibleChecks,
-    PlainDatabaseChecks):
+class TestsWorkWithTestScenariosTestCaseAndSomeScenarios(TestCaseWithScenarios,
+                                                         ScenarioParametersAreVisibleChecks,
+                                                         PlainDatabaseChecks):
     """
     Test class that is using:
         * database transactions
@@ -145,10 +142,9 @@ class TestsWorkWithTestScenariosTestCaseAndSomeScenarios(
 # Transaction tests
 
 
-class TransactionsWorkWithPlainDjangoTestCase(
-    DjangoTransactionTestCase,
-    PlainDatabaseChecks,
-    TransactionChecks):
+class TransactionsWorkWithPlainDjangoTestCase(DjangoTransactionTestCase,
+                                              PlainDatabaseChecks,
+                                              TransactionChecks):
     """
     Test class that is using:
         * database transactions
@@ -156,10 +152,9 @@ class TransactionsWorkWithPlainDjangoTestCase(
     """
 
 
-class TransactionsWorkWithTestToolsTestCase(
-    TransactionTestCase,
-    PlainDatabaseChecks,
-    TransactionChecks):
+class TransactionsWorkWithTestToolsTestCase(TransactionTestCase,
+                                            PlainDatabaseChecks,
+                                            TransactionChecks):
     """
     Test class that is using:
         * database transactions
@@ -167,10 +162,9 @@ class TransactionsWorkWithTestToolsTestCase(
     """
 
 
-class TransactionsWorkWithTestScenariosTestCaseAndNoScenarios(
-    TransactionTestCaseWithScenarios,
-    PlainDatabaseChecks,
-    TransactionChecks):
+class TransactionsWorkWithTestScenariosTestCaseAndNoScenarios(TransactionTestCaseWithScenarios,
+                                                              PlainDatabaseChecks,
+                                                              TransactionChecks):
     """
     Test class that is using:
         * database transactions
@@ -180,11 +174,10 @@ class TransactionsWorkWithTestScenariosTestCaseAndNoScenarios(
     """
 
 
-class TransactionsWorkWithTestScenariosTestCaseAndSomeScenarios(
-    TransactionTestCaseWithScenarios,
-    ScenarioParametersAreVisibleChecks,
-    PlainDatabaseChecks,
-    TransactionChecks):
+class TransactionsWorkWithTestScenariosTestCaseAndSomeScenarios(TransactionTestCaseWithScenarios,
+                                                                ScenarioParametersAreVisibleChecks,
+                                                                PlainDatabaseChecks,
+                                                                TransactionChecks):
     """
     Test class that is using:
         * database transactions
@@ -230,7 +223,7 @@ class TestReorderingNotBroken(DjangoTestCase):
         them using the same logic that Django applies and verify that
         the order is proper_order
         """
-        from django.test.simple import reorder_suite
+        from django.test.runner import reorder_suite
 
         suite = unittest.TestSuite()
         for cls in initial_order:
